==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/GetAvailabilitySetPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilitySetName Name of the AvailabilitySet.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetAvailabilitySetPlainArgs(
    public val availabilitySetName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs =
        com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs.builder()
            .availabilitySetName(availabilitySetName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAvailabilitySetPlainArgs].
 */
@PulumiTagMarker
public class GetAvailabilitySetPlainArgsBuilder internal constructor() {
    private var availabilitySetName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the AvailabilitySet.
     */
    @JvmName("krmfhmyebkwnfnob")
    public suspend fun availabilitySetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.availabilitySetName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("ftkrfmjjncglmhep")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAvailabilitySetPlainArgs = GetAvailabilitySetPlainArgs(
        availabilitySetName = availabilitySetName ?: throw PulumiNullFieldException("availabilitySetName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/GetAvailabilitySetPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilitySetName Name of the AvailabilitySet.
 * @property resourceGroupName The name of the resource group.
 */
public data class GetAvailabilitySetPlainArgs(
    public val availabilitySetName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs =
        com.pulumi.azurenative.scvmm.inputs.GetAvailabilitySetPlainArgs.builder()
            .availabilitySetName(availabilitySetName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAvailabilitySetPlainArgs].
 */
@PulumiTagMarker
public class GetAvailabilitySetPlainArgsBuilder internal constructor() {
    private var availabilitySetName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the AvailabilitySet.
     */
    @JvmName("urtdcxhqqdixeffa")
    public suspend fun availabilitySetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.availabilitySetName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("sedgvpnuqvjuomuk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAvailabilitySetPlainArgs = GetAvailabilitySetPlainArgs(
        availabilitySetName = availabilitySetName ?: throw PulumiNullFieldException("availabilitySetName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
